/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	v1 "github.com/rook/rook/pkg/apis/ceph.rook.io/v1"
	scheme "github.com/rook/rook/pkg/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// CephBlockPoolsGetter has a method to return a CephBlockPoolInterface.
// A group's client should implement this interface.
type CephBlockPoolsGetter interface {
	CephBlockPools(namespace string) CephBlockPoolInterface
}

// CephBlockPoolInterface has methods to work with CephBlockPool resources.
type CephBlockPoolInterface interface {
	Create(*v1.CephBlockPool) (*v1.CephBlockPool, error)
	Update(*v1.CephBlockPool) (*v1.CephBlockPool, error)
	Delete(name string, options *metav1.DeleteOptions) error
	DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
	Get(name string, options metav1.GetOptions) (*v1.CephBlockPool, error)
	List(opts metav1.ListOptions) (*v1.CephBlockPoolList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CephBlockPool, err error)
	CephBlockPoolExpansion
}

// cephBlockPools implements CephBlockPoolInterface
type cephBlockPools struct {
	client rest.Interface
	ns     string
}

// newCephBlockPools returns a CephBlockPools
func newCephBlockPools(c *CephV1Client, namespace string) *cephBlockPools {
	return &cephBlockPools{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the cephBlockPool, and returns the corresponding cephBlockPool object, and an error if there is any.
func (c *cephBlockPools) Get(name string, options metav1.GetOptions) (result *v1.CephBlockPool, err error) {
	result = &v1.CephBlockPool{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("cephblockpools").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of CephBlockPools that match those selectors.
func (c *cephBlockPools) List(opts metav1.ListOptions) (result *v1.CephBlockPoolList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.CephBlockPoolList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("cephblockpools").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested cephBlockPools.
func (c *cephBlockPools) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("cephblockpools").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a cephBlockPool and creates it.  Returns the server's representation of the cephBlockPool, and an error, if there is any.
func (c *cephBlockPools) Create(cephBlockPool *v1.CephBlockPool) (result *v1.CephBlockPool, err error) {
	result = &v1.CephBlockPool{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("cephblockpools").
		Body(cephBlockPool).
		Do().
		Into(result)
	return
}

// Update takes the representation of a cephBlockPool and updates it. Returns the server's representation of the cephBlockPool, and an error, if there is any.
func (c *cephBlockPools) Update(cephBlockPool *v1.CephBlockPool) (result *v1.CephBlockPool, err error) {
	result = &v1.CephBlockPool{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("cephblockpools").
		Name(cephBlockPool.Name).
		Body(cephBlockPool).
		Do().
		Into(result)
	return
}

// Delete takes name of the cephBlockPool and deletes it. Returns an error if one occurs.
func (c *cephBlockPools) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("cephblockpools").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *cephBlockPools) DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("cephblockpools").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched cephBlockPool.
func (c *cephBlockPools) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CephBlockPool, err error) {
	result = &v1.CephBlockPool{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("cephblockpools").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
