/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	v1 "github.com/rook/rook/pkg/apis/ceph.rook.io/v1"
	scheme "github.com/rook/rook/pkg/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// CephClientsGetter has a method to return a CephClientInterface.
// A group's client should implement this interface.
type CephClientsGetter interface {
	CephClients(namespace string) CephClientInterface
}

// CephClientInterface has methods to work with CephClient resources.
type CephClientInterface interface {
	Create(*v1.CephClient) (*v1.CephClient, error)
	Update(*v1.CephClient) (*v1.CephClient, error)
	Delete(name string, options *metav1.DeleteOptions) error
	DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
	Get(name string, options metav1.GetOptions) (*v1.CephClient, error)
	List(opts metav1.ListOptions) (*v1.CephClientList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CephClient, err error)
	CephClientExpansion
}

// cephClients implements CephClientInterface
type cephClients struct {
	client rest.Interface
	ns     string
}

// newCephClients returns a CephClients
func newCephClients(c *CephV1Client, namespace string) *cephClients {
	return &cephClients{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the cephClient, and returns the corresponding cephClient object, and an error if there is any.
func (c *cephClients) Get(name string, options metav1.GetOptions) (result *v1.CephClient, err error) {
	result = &v1.CephClient{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("cephclients").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of CephClients that match those selectors.
func (c *cephClients) List(opts metav1.ListOptions) (result *v1.CephClientList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.CephClientList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("cephclients").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested cephClients.
func (c *cephClients) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("cephclients").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a cephClient and creates it.  Returns the server's representation of the cephClient, and an error, if there is any.
func (c *cephClients) Create(cephClient *v1.CephClient) (result *v1.CephClient, err error) {
	result = &v1.CephClient{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("cephclients").
		Body(cephClient).
		Do().
		Into(result)
	return
}

// Update takes the representation of a cephClient and updates it. Returns the server's representation of the cephClient, and an error, if there is any.
func (c *cephClients) Update(cephClient *v1.CephClient) (result *v1.CephClient, err error) {
	result = &v1.CephClient{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("cephclients").
		Name(cephClient.Name).
		Body(cephClient).
		Do().
		Into(result)
	return
}

// Delete takes name of the cephClient and deletes it. Returns an error if one occurs.
func (c *cephClients) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("cephclients").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *cephClients) DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("cephclients").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched cephClient.
func (c *cephClients) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CephClient, err error) {
	result = &v1.CephClient{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("cephclients").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
