/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"time"

	v1 "github.com/rook/rook/pkg/apis/ceph.rook.io/v1"
	scheme "github.com/rook/rook/pkg/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// CephFilesystemsGetter has a method to return a CephFilesystemInterface.
// A group's client should implement this interface.
type CephFilesystemsGetter interface {
	CephFilesystems(namespace string) CephFilesystemInterface
}

// CephFilesystemInterface has methods to work with CephFilesystem resources.
type CephFilesystemInterface interface {
	Create(*v1.CephFilesystem) (*v1.CephFilesystem, error)
	Update(*v1.CephFilesystem) (*v1.CephFilesystem, error)
	Delete(name string, options *metav1.DeleteOptions) error
	DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
	Get(name string, options metav1.GetOptions) (*v1.CephFilesystem, error)
	List(opts metav1.ListOptions) (*v1.CephFilesystemList, error)
	Watch(opts metav1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CephFilesystem, err error)
	CephFilesystemExpansion
}

// cephFilesystems implements CephFilesystemInterface
type cephFilesystems struct {
	client rest.Interface
	ns     string
}

// newCephFilesystems returns a CephFilesystems
func newCephFilesystems(c *CephV1Client, namespace string) *cephFilesystems {
	return &cephFilesystems{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the cephFilesystem, and returns the corresponding cephFilesystem object, and an error if there is any.
func (c *cephFilesystems) Get(name string, options metav1.GetOptions) (result *v1.CephFilesystem, err error) {
	result = &v1.CephFilesystem{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("cephfilesystems").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of CephFilesystems that match those selectors.
func (c *cephFilesystems) List(opts metav1.ListOptions) (result *v1.CephFilesystemList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.CephFilesystemList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("cephfilesystems").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested cephFilesystems.
func (c *cephFilesystems) Watch(opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("cephfilesystems").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a cephFilesystem and creates it.  Returns the server's representation of the cephFilesystem, and an error, if there is any.
func (c *cephFilesystems) Create(cephFilesystem *v1.CephFilesystem) (result *v1.CephFilesystem, err error) {
	result = &v1.CephFilesystem{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("cephfilesystems").
		Body(cephFilesystem).
		Do().
		Into(result)
	return
}

// Update takes the representation of a cephFilesystem and updates it. Returns the server's representation of the cephFilesystem, and an error, if there is any.
func (c *cephFilesystems) Update(cephFilesystem *v1.CephFilesystem) (result *v1.CephFilesystem, err error) {
	result = &v1.CephFilesystem{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("cephfilesystems").
		Name(cephFilesystem.Name).
		Body(cephFilesystem).
		Do().
		Into(result)
	return
}

// Delete takes name of the cephFilesystem and deletes it. Returns an error if one occurs.
func (c *cephFilesystems) Delete(name string, options *metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("cephfilesystems").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *cephFilesystems) DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("cephfilesystems").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched cephFilesystem.
func (c *cephFilesystems) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.CephFilesystem, err error) {
	result = &v1.CephFilesystem{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("cephfilesystems").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
